@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
 module ActionMailer
-  # Returns the version of the currently loaded Action Mailer as a <tt>Gem::Version</tt>.
+  # Returns the currently loaded version of Action Mailer as a <tt>Gem::Version</tt>.
   def self.gem_version
     Gem::Version.new VERSION::STRING
   end
 
   module VERSION
-    MAJOR = 6
-    MINOR = 1
-    TINY  = 7
-    PRE   = "10"
+    MAJOR = 7
+    MINOR = 0
+    TINY  = 10
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
